@@ -280,64 +280,66 @@ gf_action_execute_open_conv(GfDisplay *display, GdkEventButton *gdk_event) {
 	GfEvent *event;
 	GfEventInfo *info;
 	GaimAccount *account = NULL;
+	GaimBuddy *buddy = NULL;
 	GaimConversation *conv = NULL;
 	GaimConvWindow *win = NULL;
-	const gchar *e_type, *n_type;
+	const GHashTable *components = NULL;
+	const gchar *n_type;
 
 	g_return_if_fail(display);
 
 	info = gf_display_get_event_info(display);
 	event = gf_event_info_get_event(info);
-	e_type = gf_event_get_event_type(event);
 	n_type = gf_event_get_notification_type(event);
 
-	if(!g_ascii_strcasecmp(e_type, "conversation")) {
-		if(!g_ascii_strcasecmp(n_type, "chat-invite")) {
-			const GHashTable *components = gf_event_info_get_components(info);
-			const gchar *extra = gf_event_info_get_extra(info);
+	account = gf_event_info_get_account(info);
+	buddy = gf_event_info_get_buddy(info);
+	conv = gf_event_info_get_conversation(info);
+	components = gf_event_info_get_components(info);
 
-			account = gf_event_info_get_account(info);
-			conv = gaim_find_conversation_with_account(extra, account);
+	if(conv) { /* we have a conv */
+		if(conversation_exists(conv)) {
+			win = gaim_conversation_get_window(conv);
+		} else { /* the conv we have doesn't exist anymore.. */
+			const gchar *target;
 
-			if(!conv && components)
-				serv_join_chat(account->gc, (GHashTable *)components);
-
-			conv = NULL;
-			gf_display_destroy(display);
-		} else {
-			conv = gf_event_info_get_conversation(info);
-
-			if(conv && conversation_exists(conv)) {
-				const gchar *target;
-
-				target = gf_event_info_get_target(info);
-				account = gf_event_info_get_account(info);
-
-				if(target && account)
-					conv = gaim_find_conversation_with_account(target, account);
-			}
+			target = gf_event_info_get_target(info);
+			conv = gaim_find_conversation_with_account(target, account);
 
 			if(conv)
 				win = gaim_conversation_get_window(conv);
 		}
-	} else if(!g_ascii_strcasecmp(e_type, "buddy")) {
-		GaimBuddy *buddy;
+	} else if(components) { /* it's a chat invite */
+		const gchar *extra = gf_event_info_get_extra(info);
 
-		buddy = gf_event_info_get_buddy(info);
-		conv = gaim_conversation_new(GAIM_CONV_IM,
-									 gf_event_info_get_account(info),
-									 buddy->name);
-		win = gaim_conversation_get_window(conv);
-	} else if(!g_ascii_strcasecmp(e_type, "account")) {
-		if(!g_ascii_strcasecmp(n_type, "warned")) {
-			const gchar *target = NULL;
+		conv = gaim_find_conversation_with_account(extra, account);
+		if(!conv) {
+			serv_join_chat(account->gc, (GHashTable *)components);
+			gf_display_destroy(display);
 
-			if((target = gf_event_info_get_target(info))) {
-				conv = gaim_conversation_new(GAIM_CONV_IM,
-											 gf_event_info_get_account(info),
-											 target);
+			return;
+		}
+	} else if (buddy) { /* we have a buddy */
+		conv = gaim_find_conversation_with_account(buddy->name, account);
+
+		if(!conv)
+			conv = gaim_conversation_new(GAIM_CONV_IM, account, buddy->name);
+
+		if(conv)
+			win = gaim_conversation_get_window(conv);
+	} else { /* the only thing that _should_ be left is warnings.. */
+		const gchar *target;
+
+		target = gf_event_info_get_target(info);
+
+		if(target) {
+			conv = gaim_find_conversation_with_account(target, account);
+
+			if(!conv)
+				conv = gaim_conversation_new(GAIM_CONV_IM, account, target);
+
+			if(conv)
 				win = gaim_conversation_get_window(conv);
-			}
 		}
 	}
 
@@ -354,41 +356,27 @@ gf_action_execute_open_conv(GfDisplay *display, GdkEventButton *gdk_event) {
 
 void
 gf_action_execute_info(GfDisplay *display, GdkEventButton *gdk_event) {
-	GfEvent *event;
 	GfEventInfo *info;
-	const gchar *e_type, *n_type;
+	const gchar *target;
 	GaimAccount *account;
 
 	g_return_if_fail(display);
 
 	info = gf_display_get_event_info(display);
 	account = gf_event_info_get_account(info);
-	event = gf_event_info_get_event(info);
+	target = gf_event_info_get_target(info);
 
-	e_type = gf_event_get_event_type(event);
-	n_type = gf_event_get_notification_type(event);
+	/* This covers everything.
+	 *
+	 * We used to make a distinction between event types, but since we store
+	 * the target for every event, and how you can't get info about a chat
+	 * we just use the target.  The target for a buddy event is the
+	 * buddy->name, in a warning event it's the screen name of the person
+	 * who warned you, and in a chat it's the person that said something.
+	 */
+	if(target) {
+		serv_get_info(account->gc, target);
 
-	if(!g_ascii_strcasecmp(e_type, "account")) {
-		if(!g_ascii_strcasecmp(n_type, "warned")) {
-			serv_get_info(account->gc, gf_event_info_get_target(info));
-
-			gf_display_destroy(display);
-		}
-	} else if(!g_ascii_strcasecmp(e_type, "buddy")) {
-		GaimBuddy *buddy;
-
-		if((buddy = gf_event_info_get_buddy(info)))
-			serv_get_info(account->gc, buddy->name);
-
-		gf_display_destroy(display);
-	} else if(!g_ascii_strcasecmp(e_type, "conversation")) {
-		GaimConversation *conv;
-
-		if((conv = gf_event_info_get_conversation(info)))
-			if(gaim_conversation_get_type(conv) == GAIM_CONV_IM)
-				serv_get_info(account->gc, gf_event_info_get_target(info));
-
-		/* theres no way to get info about a chat so we just destroy */
 		gf_display_destroy(display);
 	}
 }
@@ -398,38 +386,30 @@ gf_action_execute_log(GfDisplay *display, GdkEventButton *gdk_event) {
 	GfEvent *event;
 	GfEventInfo *info;
 	GaimAccount *account;
-	const gchar *e_type, *n_type;
+	GaimConversation *conv;
+	const gchar *n_type, *target;
 
 	g_return_if_fail(display);
 
 	info = gf_display_get_event_info(display);
+
 	account = gf_event_info_get_account(info);
 	event = gf_event_info_get_event(info);
-	e_type = gf_event_get_event_type(event);
+	conv = gf_event_info_get_conversation(info);
+	target = gf_event_info_get_target(info);
+
 	n_type = gf_event_get_notification_type(event);
 
-	if(!g_ascii_strcasecmp(e_type, "account")) {
-		if(!g_ascii_strcasecmp(n_type, "warned")) {
-			gaim_gtk_log_show(GAIM_LOG_IM, gf_event_info_get_target(info), account);
+	if(conv) {
+		GaimConversationType type;
 
+		type = gaim_conversation_get_type(conv);
+		if(type == GAIM_CONV_IM || type == GAIM_CONV_CHAT) {
+			gaim_gtk_log_show(type, (type == GAIM_CONV_IM) ? target : conv->name, account); 
 			gf_display_destroy(display);
 		}
-	} else if(!g_ascii_strcasecmp(e_type, "buddy")) {
-		GaimBuddy *buddy;
-
-		if((buddy = gf_event_info_get_buddy(info)))
-			gaim_gtk_log_show(GAIM_LOG_IM, buddy->name, account);
-
-		gf_display_destroy(display);
-	} else if(!g_ascii_strcasecmp(e_type, "conversation")) {
-		GaimConversation *conv;
-
-		if((conv = gf_event_info_get_conversation(info))) {
-			if(gaim_conversation_get_type(conv) == GAIM_CONV_IM)
-				gaim_gtk_log_show(GAIM_LOG_IM, gf_event_info_get_target(info), account);
-			else if(gaim_conversation_get_type(conv) == GAIM_CONV_CHAT)
-				gaim_gtk_log_show(GAIM_LOG_CHAT, conv->name, account);
-		}
+	} else if(target) {
+		gaim_gtk_log_show(GAIM_CONV_IM, target, account);
 
 		gf_display_destroy(display);
 	}
