@@ -33,6 +33,8 @@ typedef BOOL WINAPI GF_GetMonitorInfo(HMONITOR,LPMONITORINFO);
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
+#include <math.h>
+#include <string.h>
 
 #include <debug.h>
 #include <prefs.h>
@@ -42,32 +44,73 @@ typedef BOOL WINAPI GF_GetMonitorInfo(HMONITOR,LPMONITORINFO);
 #include "gf_notification.h"
 #include "gf_preferences.h"
 
+typedef enum {
+	GF_DISPLAY_STATE_UNKNOWN = 0,
+	GF_DISPLAY_STATE_SHOWING,
+	GF_DISPLAY_STATE_SHOWN,
+	GF_DISPLAY_STATE_HIDING,
+	GF_DISPLAY_STATE_DESTROYED
+} GfDisplayState;
+
 struct _GfDisplay {
+	/* Widgets */
 	GtkWidget *window;
 	GtkWidget *event;
 	GtkWidget *image;
+
+	/* Display stuff */
+	GfDisplayState state;
 	GdkPixbuf *pixbuf;
+	GdkRectangle partial;
 	gboolean has_alpha;
-
-	GfEventInfo *info;
-
 	gint height;
 	gint width;
 	gint x;
 	gint y;
 
+	/* Timer intervals */
+	gint anim_time;
+	gint disp_time;
+
+	/* Animation stuff */
+	gint round;
+	gint rounds;
+
+	/* Action stuff */
+	GfEventInfo *info;
 	guint button;
 };
 
 #include "gf_display.h"
 
+/*******************************************************************************
+ * consts/macros
+ ******************************************************************************/
+#define GF_DISPLAY_ROUND(x)	((x)+0.5)
+
+static const double DELTA_SIZE = 1.333;
+static const gint DELTA_TIME = 33.33;
+
 /*******************************************************************************
  * Globals
  ******************************************************************************/
 static GList *displays = NULL;
+static gboolean vertical, animate;
+static GfDisplayPosition position;
+
 #if GTK_CHECK_VERSION(2,2,0)
 static gint disp_screen = 0, disp_monitor = 0;
-#endif
+#endif /* GTK_CHECK_VERSION(2,2,0) */
+
+/*******************************************************************************
+ * Prototypes...
+ *
+ * Yeah, I know they're bad, but sometimes you just can't avoid them...
+ *
+ * Well, I could, but it'd add more complication...
+ ******************************************************************************/
+static gboolean gf_display_shown_cb(gpointer data);
+static gboolean gf_display_animate_cb(gpointer data);
 
 /*******************************************************************************
  * Callbacks
@@ -157,6 +200,7 @@ win32_adjust_workarea_multi_monitor(GdkRectangle *rect) {
 		monitorRect.left += virtual_screen_x;
 		monitorRect.right += virtual_screen_x;
 	}
+
 	if (virtual_screen_y != 0) {
 		monitorRect.top += virtual_screen_y;
 		monitorRect.bottom += virtual_screen_y;
@@ -220,8 +264,8 @@ gf_display_get_workarea(GdkRectangle *rect) {
 	Atom xa_desktops, xa_current, xa_workarea, xa_type;
 	Display *x_display;
 	Window x_root;
-	guint32 *workareas, desktops = 0, current = 0;
-	gulong len, fill;
+	guint32 desktops = 0, current = 0;
+	gulong *workareas, len, fill;
 	guchar *data;
 	gint format;
 
@@ -324,12 +368,12 @@ gf_display_get_workarea(GdkRectangle *rect) {
 		return FALSE;
 
 	/* it's good, lets use it */
-	workareas = (guint32 *)data;
+	workareas = (gulong *)(guint32 *)data;
 
-	rect->x = workareas[current * 4];
-	rect->y = workareas[current * 4 + 1];
-	rect->width = workareas[current * 4 + 2];
-	rect->height = workareas[current * 4 + 3];
+	rect->x = (guint32)workareas[current * 4];
+	rect->y = (guint32)workareas[current * 4 + 1];
+	rect->width = (guint32)workareas[current * 4 + 2];
+	rect->height = (guint32)workareas[current * 4 + 3];
 
 	/* clean up our memory */
 	XFree(data);
@@ -364,8 +408,22 @@ static void
 gf_display_shape(GfDisplay *display) {
 	if(display->has_alpha) {
 		GdkBitmap *bitmap = NULL;
+		GdkPixbuf *pixbuf;
 
-		gdk_pixbuf_render_pixmap_and_mask(display->pixbuf, NULL, &bitmap, 255);
+		if(display->state == GF_DISPLAY_STATE_SHOWING ||
+		   display->state == GF_DISPLAY_STATE_HIDING)
+		{
+			pixbuf = gtk_image_get_pixbuf(GTK_IMAGE(display->image));
+
+			if(!pixbuf) {
+				/* image has no pixbuf.. so we have no business continuing */
+				return;
+			}
+		} else {
+			pixbuf = display->pixbuf;
+		}
+
+		gdk_pixbuf_render_pixmap_and_mask(pixbuf, NULL, &bitmap, 255);
 		if(bitmap) {
 			gtk_widget_shape_combine_mask(display->window, bitmap, 0, 0);
 			g_object_unref(G_OBJECT(bitmap));
@@ -414,15 +472,29 @@ gf_display_get_geometry(gint *x, gint *y, gint *width, gint *height) {
 static void
 gf_display_shape(GfDisplay *display) {
 	if(display->has_alpha) {
-		GdkScreen *screen;
-		GdkColormap *cmap;
 		GdkBitmap *bmap;
+		GdkColormap *cmap;
+		GdkPixbuf *pixbuf;
+		GdkScreen *screen;
 
 		screen = gdk_display_get_screen(gdk_display_get_default(), disp_screen);
 		cmap = gdk_screen_get_system_colormap(screen);
 
-		gdk_pixbuf_render_pixmap_and_mask_for_colormap(display->pixbuf,
-													   cmap, NULL, &bmap, 255);
+		if(display->state == GF_DISPLAY_STATE_SHOWING ||
+		   display->state == GF_DISPLAY_STATE_HIDING)
+		{
+			pixbuf = gtk_image_get_pixbuf(GTK_IMAGE(display->image));
+
+			if(!pixbuf) {
+				/* image has no pixbuf.. so we have no business continuing */
+				return;
+			}
+		} else {
+			pixbuf = display->pixbuf;
+		}
+
+		gdk_pixbuf_render_pixmap_and_mask_for_colormap(pixbuf, cmap, NULL,
+													   &bmap, 255);
 
 		if(bmap) {
 			gtk_widget_shape_combine_mask(display->window, bmap, 0, 0);
@@ -497,14 +569,13 @@ static void
 gf_display_position(GfDisplay *new_display) {
 	GfDisplay *display;
 	GList *l = NULL;
-	gint pad_x = 0, pad_y = 0, width = 0, height = 0;
+	gint pad_x = 0, pad_y = 0;
+	gint disp_width = 0, disp_height = 0;
+	gint width = 0, height = 0;
 	gint total = 0;
-	gboolean vertical;
 
 	g_return_if_fail(new_display);
 
-	vertical = gaim_prefs_get_bool(GF_PREF_APPEARANCE_VERTICAL);
-
 	gf_display_get_geometry(&pad_x, &pad_y, &width, &height);
 
 	for(l = displays; l; l = l->next) {
@@ -519,7 +590,20 @@ gf_display_position(GfDisplay *new_display) {
 			total += display->width;
 	}
 
-	switch(gaim_prefs_get_int(GF_PREF_APPEARANCE_POSITION)) {
+	if(new_display->state == GF_DISPLAY_STATE_SHOWING ||
+	   new_display->state == GF_DISPLAY_STATE_HIDING)
+	{
+		disp_width = new_display->partial.width;
+		disp_height = new_display->partial.height;
+	} else {
+		disp_width = new_display->width;
+		disp_height = new_display->height;
+	}
+
+	/* set the correct size for the window */
+	gtk_widget_set_size_request(new_display->window, disp_width, disp_height);
+
+	switch(position) {
 		case GF_DISPLAY_POSITION_NW:
 			if(vertical) {
 				new_display->x = pad_x;
@@ -532,10 +616,10 @@ gf_display_position(GfDisplay *new_display) {
 			break;
 		case GF_DISPLAY_POSITION_NE:
 			if(vertical) {
-				new_display->x = pad_x + width - new_display->width;
+				new_display->x = pad_x + width - disp_width;
 				new_display->y = pad_y + total;
 			} else {
-				new_display->x = pad_x + width - (total + new_display->width);
+				new_display->x = pad_x + width - (total + disp_width);
 				new_display->y = pad_y;
 			}
 
@@ -543,20 +627,20 @@ gf_display_position(GfDisplay *new_display) {
 		case GF_DISPLAY_POSITION_SW:
 			if(vertical) {
 				new_display->x = pad_x;
-				new_display->y = pad_y + height - (total + new_display->height);
+				new_display->y = pad_y + height - (total + disp_height);
 			} else {
 				new_display->x = pad_x + total;
-				new_display->y = pad_y + height - (new_display->height);
+				new_display->y = pad_y + height - (disp_height);
 			}
 
 			break;
 		case GF_DISPLAY_POSITION_SE:
 			if(vertical) {
-				new_display->x = pad_x + width - new_display->width;
-				new_display->y = pad_y + height - (total + new_display->height);
+				new_display->x = pad_x + width - disp_width;
+				new_display->y = pad_y + height - (total + disp_height);
 			} else {
-				new_display->x = pad_x + width - (total + new_display->width);
-				new_display->y = pad_y + height - new_display->height;
+				new_display->x = pad_x + width - (total + disp_width);
+				new_display->y = pad_y + height - disp_height;
 			}
 
 			break;
@@ -615,6 +699,223 @@ gf_display_destroy(GfDisplay *display) {
 	gf_displays_position();
 }
 
+static gboolean
+gf_display_shown_cb(gpointer data) {
+	GfDisplay *display = GF_DISPLAY(data);
+	guint timeout_id;
+
+	/* in case something wicked happened */
+	g_return_val_if_fail(display, FALSE);
+
+	display->state = GF_DISPLAY_STATE_HIDING;
+
+	timeout_id = g_timeout_add(DELTA_TIME, gf_display_animate_cb, data);
+	gf_event_info_set_timeout_id(display->info, timeout_id);
+
+	return FALSE;
+}
+
+static gint
+gf_display_calculate_change(GfDisplay *display, gint maximum) {
+	/* This function calculates an an exponential change.
+	 *
+	 * It's a basic scalable exponential movement formula, given to us by
+	 * Nathaniel Waters.
+	 */
+	gint ret;
+
+	/* this could probably use some type casting somewhere.. */
+	ret = GF_DISPLAY_ROUND(((gdouble)maximum /
+		  pow(DELTA_SIZE, display->rounds)) *
+		  pow(DELTA_SIZE, display->round));
+
+	return ret;
+}
+
+static gboolean
+gf_display_animate(GfDisplay *display) {
+	GdkPixbuf *pixbuf;
+	GdkRectangle full;
+	gint total, current;
+	gboolean ret = TRUE;
+
+	/* figure out what we're modifing */
+	if(vertical)
+		total = display->height;
+	else
+		total = display->width;
+
+	/* calculate the change */
+	current = gf_display_calculate_change(display, total);
+
+	/* create our rects */
+	full.x = 0;
+	full.y = 0;
+	full.width = display->width;
+	full.height = display->height;
+
+	/* ugh too many possibilities */
+	switch(position) {
+		case GF_DISPLAY_POSITION_NW:
+			if(vertical) {
+				display->partial.x = full.x;
+				display->partial.y = full.height - current;
+				display->partial.width = full.width;
+				display->partial.height = current;
+			} else {
+				display->partial.x = full.width - current;
+				display->partial.y = full.y;
+				display->partial.width = current;
+				display->partial.height = full.height;
+			}
+
+			break;
+		case GF_DISPLAY_POSITION_NE:
+			if(vertical) {
+				display->partial.x = full.x;
+				display->partial.y = full.y;
+				display->partial.width = full.width;
+				display->partial.height = current;
+			} else {
+				display->partial.x = full.x;
+				display->partial.y = full.y;
+				display->partial.width = current;
+				display->partial.height = full.height;
+			}
+
+			break;
+		case GF_DISPLAY_POSITION_SW:
+			if(vertical) {
+				display->partial.x = full.x;
+				display->partial.y = full.y;
+				display->partial.width = full.width;
+				display->partial.height = current;
+			} else {
+				display->partial.x = full.width - current;
+				display->partial.y = full.y;
+				display->partial.width = current;
+				display->partial.height = full.height;
+			}
+
+			break;
+		case GF_DISPLAY_POSITION_SE:
+			if(vertical) {
+				display->partial.x = full.x;
+				display->partial.y = full.y;
+				display->partial.width = full.width;
+				display->partial.height = current;
+			} else {
+				display->partial.x = full.x;
+				display->partial.y = full.y;
+				display->partial.width = current;
+				display->partial.height = full.height;
+			}
+
+			break;
+		default:
+			display->partial.x = full.x;
+			display->partial.y = full.y;
+			display->partial.width = full.width;
+			display->partial.height = full.height;
+
+			break;
+	}
+
+	/* Add some sanity checks */
+	if(display->partial.width <= 0)
+		display->partial.width = 1;
+	if(display->partial.height <= 0)
+		display->partial.height = 1;
+
+	/* create our partial pixbuf and fill it */
+	pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, display->has_alpha,	8,
+							display->partial.width, display->partial.height);
+
+	if(!pixbuf) {
+		gaim_debug_info("guifications", "failed to created partial pixbuf, "
+						"destroying display %p\n", display);
+		gf_display_destroy(display);
+
+		return FALSE;
+	}
+
+	gdk_pixbuf_copy_area(display->pixbuf,
+						 display->partial.x, display->partial.y,
+						 display->partial.width, display->partial.height,
+						 pixbuf, 0, 0);
+
+	/* force the image and event box to be the same size as the partial
+	 * pixbuf
+	 */
+	gtk_widget_set_size_request(display->image, display->partial.width,
+								display->partial.height);
+	gtk_widget_set_size_request(display->event, display->partial.width,
+								display->partial.height);
+
+	/* update the image's pixbuf */
+	gtk_image_set_from_pixbuf(GTK_IMAGE(display->image), pixbuf);
+
+	/* unref the partial pixbuf */
+	g_object_unref(G_OBJECT(pixbuf));
+
+	/* update the display and force gdk to redraw it */
+	gf_display_shape(display);
+	gf_display_position(display);
+	gdk_window_process_updates(GDK_WINDOW(display->window->window), TRUE);
+
+	/* Finish up */
+	if(display->state == GF_DISPLAY_STATE_SHOWING) {
+		display->round++;
+
+		if(display->round > display->rounds) {
+			guint timeout_id;
+
+			/* set rounds back to the max */
+			display->round = display->rounds - 1;
+
+			display->state = GF_DISPLAY_STATE_SHOWN;
+
+			timeout_id = gtk_timeout_add(display->disp_time,
+										 gf_display_shown_cb,
+										 (gpointer)display);
+			gf_event_info_set_timeout_id(display->info, timeout_id);
+
+			ret = FALSE;
+		}
+	} else { /* if(display->state == GF_DISPLAY_STATE_HIDING) { */
+		display->round--;
+
+		if(display->round <= 0) {
+			gf_display_destroy(display);
+
+			ret = FALSE;
+		}
+	}
+
+	return ret;
+}
+
+static gboolean
+gf_display_animate_cb(gpointer data) {
+	GfDisplay *display = GF_DISPLAY(data);
+	gboolean ret;
+
+	/* in the event something wicked happened... */
+	g_return_val_if_fail(display, FALSE);
+
+	/* we call a function to do our animation here to modularize the process
+	 * so we can do other types of animation, like fading depending on other
+	 * conditions.  These conditions should be checked here, and then called
+	 * accordingly.
+	 *
+	 * The animation function should return a boolean so we can tell the
+	 * timer handler whether or not to keep the timer around.
+	 */
+	ret = gf_display_animate(display);
+
+	return ret;
+}
+
 static gboolean
 gf_display_destroy_cb(gpointer data) {
 	GfDisplay *display = GF_DISPLAY(data);
@@ -624,115 +925,135 @@ gf_display_destroy_cb(gpointer data) {
 	return FALSE;
 }
 
-static void
-gf_display_condense_contacts(GfEventInfo *info) {
-	GaimBuddy *buddy1, *buddy2;
-	GaimContact *contact1, *contact2;
-	GList *l, *ll;
+/* Yes this big ugly function has a purpose...
+ * It checks for existing notification from the same buddy, or conv with 
+ * with the same target, and condenses contacts.
+ *
+ * It returns TRUE if the new notification/event should be destroyed because
+ * theres a matching notification that has a higher priority than the new
+ * notification/event
+ */
+static gboolean
+gf_display_condense(GfEventInfo *info) {
+	GfDisplay *display = NULL;
+	GfEvent *event1 = NULL, *event2 = NULL;
+	GfEventPriority priority1, priority2;
+	GaimBuddy *buddy1 = NULL, *buddy2 = NULL;
+	GaimContact *contact1 = NULL, *contact2 = NULL;
+	GaimConversation *conv1 = NULL, *conv2 = NULL;
+	GList *l = NULL, *ll = NULL;
+	gchar *ck1 = NULL, *ck2 = NULL;
+	const gchar *target1 = NULL, *target2 = NULL;
+	gboolean ret = FALSE;
+
+	event1 = gf_event_info_get_event(info);
+	priority1 = gf_event_get_priority(event1);
 
 	buddy1 = gf_event_info_get_buddy(info);
-	if(!buddy1)
-		return;
+	conv1 = gf_event_info_get_conversation(info);
+	target1 = gf_event_info_get_target(info);
 
-	contact1 = gaim_buddy_get_contact(buddy1);
-	if(!contact1)
-		return;
+	if(buddy1)
+		contact1 = gaim_buddy_get_contact(buddy1);
+
+	if(target1)
+		ck1 = g_utf8_collate_key(target1, -1);
 
 	for(l = displays; l; l = ll) {
-		GfDisplay *display;
-
-		ll = l->next;
 		display = GF_DISPLAY(l->data);
-
-		buddy2 = gf_event_info_get_buddy(display->info);
-		if(!buddy2)
-			continue;
-
-		if(!g_ascii_strcasecmp(buddy1->name, buddy2->name) &&
-		   buddy1->account == buddy2->account) {
-			continue;
-		}
-
-		contact2 = gaim_buddy_get_contact(buddy2);
-
-		if(contact1 == contact2) {
-			gf_event_info_set_is_contact(info, TRUE);
-			gf_display_destroy(display);
-		}
-	}
-
-	gf_displays_position();
-}
-
-static void
-gf_display_condense(GfEventInfo *info) {
-	GfDisplay *display;
-	GaimBuddy *buddy;
-	GaimConversation *conv;
-	GList *l, *ll;
-	const gchar *target;
-
-	gf_display_condense_contacts(info);
-
-	buddy = gf_event_info_get_buddy(info);
-	conv = gf_event_info_get_conversation(info);
-	target = gf_event_info_get_target(info);
-
-	for(l = displays; l; l = ll) {
 		ll = l->next;
 
-		display = GF_DISPLAY(l->data);
+		event2 = gf_event_info_get_event(display->info);
+		priority2 = gf_event_get_priority(event2);
 
-		if(buddy && buddy == gf_event_info_get_buddy(display->info)) {
-			
-			gf_display_destroy(display);
-			continue;
+		conv2 = gf_event_info_get_conversation(display->info);
+
+		if(buddy1) {
+			buddy2 = gf_event_info_get_buddy(display->info);
+
+			/* check contacts */
+			if(buddy2) {
+				contact2 = gaim_buddy_get_contact(buddy2);
+
+				if(contact1 && contact1 == contact2) {
+					ck2 = g_utf8_collate_key(buddy2->name, -1);
+
+					if(!(buddy1->account == buddy2->account &&
+					    !strcmp(ck1, ck2)))
+					{
+						if(priority1 >= priority2) {
+							gf_event_info_set_is_contact(info, TRUE);
+							gf_display_destroy(display);
+							continue;
+						} else {
+							ret = TRUE;
+							break;
+						}
+					}
+
+					g_free(ck2);
+				}
+			}
+
+			/* check for duplicate buddies */
+			if(buddy1 == buddy2) {
+				if(priority1 >= priority2) {
+					gf_display_destroy(display);
+					continue;
+				} else {
+					ret = TRUE;
+					break;
+				}
+			}
 		}
 
-		if(!target)
-			continue;
+		/* check for duplicate targets from the same conv */
+		if(ck1 && conv1 && conv1 == conv2) {
+			target2 = gf_event_info_get_target(display->info);
 
-		if(conv && conv == gf_event_info_get_conversation(display->info)) {
-			const gchar *dtarget = gf_event_info_get_target(display->info);
+			if(target2)
+				ck2 = g_utf8_collate_key(target2, -1);
 
-			if(!dtarget)
-				continue;
+			if(ck2 && !strcmp(ck1, ck2)) {
+				g_free(ck2);
 
-			if(!g_ascii_strcasecmp(target, dtarget)) {
-				gf_display_destroy(display);
-				continue;
+				if(priority1 >= priority2) {
+					gf_display_destroy(display);
+					continue;
+				} else {
+					ret = TRUE;
+					break;
+				}
 			}
 		}
 	}
-}
 
-static void
-gf_display_throttle() {
-	GfDisplay *display;
-	gint throttle;
-	guint length;
+	if(ck1)
+		g_free(ck1);
 
-	throttle = gaim_prefs_get_int(GF_PREF_BEHAVIOR_THROTTLE);
+	/* we only check the stack count if ret is true, because that means one
+	 * has been removed, so we have space.
+	 */
+	if(ret == FALSE) {
+		gint throttle = gaim_prefs_get_int(GF_PREF_BEHAVIOR_THROTTLE);
 
-	if(throttle == 0)
-		return;
+		if(throttle > 0 && g_list_length(displays) + 1 > throttle) {
+			display = GF_DISPLAY(g_list_nth_data(displays, 0));
 
-	length = g_list_length(displays);
+			if(display)
+				gf_display_destroy(display);
 
-	if(length + 1 <= throttle)
-		return;
+			gf_displays_position();
+		}
+	}
 
-	display = GF_DISPLAY(g_list_nth_data(displays, 0));
-	if(display)
-		gf_display_destroy(display);
-
-	gf_displays_position();
+	return ret;
 }
 
 gboolean
 gf_display_screen_saver_is_running() {
 	gboolean ret = FALSE;
-# ifndef _WIN32
+#ifndef _WIN32
 	static Atom xss, locked, blanked;
 	static gboolean init = FALSE;
 	Atom ratom;
@@ -795,11 +1116,13 @@ gf_display_show_event(GfEventInfo *info, GfNotification *notification) {
 		return;
 	}
 
-	/* condense contacts and same buddy notifications */
-	gf_display_condense(info);
-
-	/* do our throttling */
-	gf_display_throttle();
+	/* condense contacts and same buddy notifications, a return value of TRUE
+	 * means theres a higher priority notification already being displayed
+	 */
+	if(gf_display_condense(info)) {
+		gf_event_info_destroy(info);
+		return;
+	}
 
 	/* create the display */
 	display = gf_display_new();
@@ -818,7 +1141,7 @@ gf_display_show_event(GfEventInfo *info, GfNotification *notification) {
 		return;
 	}
 
-	/* grab info about the pixbuf and scale it */
+	/* grab info about the pixbuf */
 	display->has_alpha = gdk_pixbuf_get_has_alpha(display->pixbuf);
 	display->height = gdk_pixbuf_get_height(display->pixbuf);
 	display->width = gdk_pixbuf_get_width(display->pixbuf);
@@ -827,27 +1150,71 @@ gf_display_show_event(GfEventInfo *info, GfNotification *notification) {
 	display->window = gtk_window_new(GTK_WINDOW_POPUP);
 	gtk_window_set_role(GTK_WINDOW(display->window), "guification");
 
-    /* now we create all our mouse signals that should play nice with other apps.. */
-	g_signal_connect(G_OBJECT(display->window), "button-press-event",
-					 G_CALLBACK(gf_display_button_press_cb), (gpointer)display);
-	g_signal_connect(G_OBJECT(display->window), "button-release-event",
-					 G_CALLBACK(gf_display_button_press_cb), (gpointer)display);
-
+	/* Create the event box, you know, so the mouse works! */
 	display->event = gtk_event_box_new();
 	if(!gtk_check_version(2,4,0))
 		g_object_set(G_OBJECT(display->event), "visible-window", FALSE, NULL);
 	gtk_container_add(GTK_CONTAINER(display->window), display->event);
 
-	display->image = gtk_image_new_from_pixbuf(display->pixbuf);
+    /* now we create all our mouse signals that should play nice with
+	 * other apps..
+	 */
+	g_signal_connect(G_OBJECT(display->window), "button-press-event",
+					 G_CALLBACK(gf_display_button_press_cb),
+					 (gpointer)display);
+	g_signal_connect(G_OBJECT(display->window), "button-release-event",
+					 G_CALLBACK(gf_display_button_press_cb),
+					 (gpointer)display);
+
+	/* create the image but don't put the pixbuf in it quite yet. */
+	display->image = gtk_image_new();
 	gtk_container_add(GTK_CONTAINER(display->event), display->image);
 
-	/* This is handled differently on gtk >= 2.2.0 */
-	gf_display_shape(display);
+	/* grab the display time */
+	display_time = 1000 * gaim_prefs_get_int(GF_PREF_BEHAVIOR_DISPLAY_TIME);
+
+	/* animation is set, this is a new notification, so we animate it */
+	if(animate) {
+		/* we explicitly set the size request because the window is created
+		 * with an image with no child, so it defaults to some insane size.
+		 */
+		gtk_widget_set_size_request(display->window,
+									display->width, display->height);
+
+		/* calculate our timer intervals.  anim_time is used for showing and
+		 * hiding, so that's 2/8ths which is 1/4th.
+		 *
+		 * Remember display time is stored in seconds!
+		 */
+		display->anim_time = display_time / 8;
+		display->disp_time = display_time * 3 / 4;
+
+		/* Calculate and store some more information about animating */
+		display->rounds = GF_DISPLAY_ROUND((gfloat)display->anim_time / 
+										   (gfloat)DELTA_TIME);
+		display->round = 0;
+
+		/* Set the state of the display */
+		display->state = GF_DISPLAY_STATE_SHOWING;
+
+		/* setup a timeout of DELTA_TIME ms for animating */
+		timeout_id = g_timeout_add(DELTA_TIME, gf_display_animate_cb,
+								   (gpointer)display);
+	} else { /* no animation! */
+		/* set the image since we're not animating */
+		gtk_image_set_from_pixbuf(GTK_IMAGE(display->image), display->pixbuf);
+
+		/* shape it */
+		gf_display_shape(display);
+
+		/* We're showing! */
+		display->state = GF_DISPLAY_STATE_SHOWN;
+
+		/* build our timeout */
+		timeout_id = g_timeout_add(display_time, gf_display_destroy_cb,
+								   (gpointer)display);
+	}
 
-	/* setup the timeout */
-	display_time = gaim_prefs_get_int(GF_PREF_BEHAVIOR_DISPLAY_TIME);
-	timeout_id = g_timeout_add(display_time * 1000, gf_display_destroy_cb,
-							   (gpointer)display);
 	gf_event_info_set_timeout_id(info, timeout_id);
 
 	/* position and show the widget */
@@ -869,9 +1236,19 @@ static void
 gf_display_position_changed_cb(const gchar *name, GaimPrefType type,
 							   gpointer val, gpointer data)
 {
+	vertical = gaim_prefs_get_bool(GF_PREF_APPEARANCE_VERTICAL);
+	position = gaim_prefs_get_int(GF_PREF_APPEARANCE_POSITION);
+
     gf_displays_position();
 }
 
+static void
+gf_display_animate_changed_cb(const gchar *name, GaimPrefType type,
+							  gpointer val, gpointer data)
+{
+	animate = GPOINTER_TO_INT(val);
+}
+
 /*******************************************************************************
  * Pref callbacks for the display/screen/monitor stuff
  ******************************************************************************/
@@ -900,17 +1277,30 @@ static guint scr_chg_id = 0, mon_chg_id = 0;
 /*******************************************************************************
  * Regular pref callbacks
  ******************************************************************************/
-static guint pos_chg_id = 0, ver_chg_id = 0;
+static guint pos_chg_id = 0, ver_chg_id = 0, ani_chg_id = 0;
 
 void
 gf_display_init() {
+	/* since we just use the callbacks to get the changes we need to know
+	 * what these are initially at.
+	 */
+	position = gaim_prefs_get_int(GF_PREF_APPEARANCE_POSITION);
+	vertical = gaim_prefs_get_bool(GF_PREF_APPEARANCE_VERTICAL);
+	animate = gaim_prefs_get_bool(GF_PREF_APPEARANCE_ANIMATE);
+
+	/* Connect our pref callbacks */
 	pos_chg_id = gaim_prefs_connect_callback(GF_PREF_APPEARANCE_POSITION,
 											 gf_display_position_changed_cb,
 											 NULL);
 	ver_chg_id = gaim_prefs_connect_callback(GF_PREF_APPEARANCE_VERTICAL,
 											 gf_display_position_changed_cb,
 											 NULL);
+	ani_chg_id = gaim_prefs_connect_callback(GF_PREF_APPEARANCE_ANIMATE,
+											 gf_display_animate_changed_cb,
+											 NULL);
+
 #if GTK_CHECK_VERSION(2,2,0)
+	/* setup our multi screen prefs */
 	disp_screen = gaim_prefs_get_int(GF_PREF_ADVANCED_SCREEN);
 	disp_monitor = gaim_prefs_get_int(GF_PREF_ADVANCED_MONITOR);
 
