@@ -37,11 +37,12 @@
 #include "gf_release.h"
 
 struct _GfEvent {
-	gchar *e_type;
 	gchar *n_type;
 	gchar *name;
 	gchar *description;
 
+	GfEventPriority priority;
+
 	gchar *tokens;
 
 	gboolean show;
@@ -53,18 +54,19 @@ static GList *events = NULL;
  * API
  ******************************************************************************/
 GfEvent *
-gf_event_new(const gchar *event_type, const gchar *notification_type,
-			 const gchar *tokens, const gchar *name, const gchar *description)
+gf_event_new(const gchar *notification_type, const gchar *tokens,
+			 const gchar *name, const gchar *description,
+			 GfEventPriority priority)
 {
 	GfEvent *event;
 
-	g_return_val_if_fail(event_type, NULL);
 	g_return_val_if_fail(notification_type, NULL);
 	g_return_val_if_fail(name, NULL);
 	g_return_val_if_fail(description, NULL);
 
 	event = g_new0(GfEvent, 1);
-	event->e_type = g_strdup(event_type);
+
+	event->priority = priority;
 	event->n_type = g_strdup(notification_type);
 
 	if(tokens)
@@ -85,20 +87,6 @@ gf_event_new(const gchar *event_type, const gchar *notification_type,
 	return event;
 }
 
-GfEvent *
-gf_event_find_for_type(const gchar *type) {
-	GfEvent *event;
-	GList *l;
-
-	for(l = events; l; l = l->next) {
-		event = GF_EVENT(l->data);
-		if(!g_ascii_strcasecmp(event->e_type, type))
-			return event;
-	}
-
-	return NULL;
-}
-
 GfEvent *
 gf_event_find_for_notification(const gchar *type) {
 	GfEvent *event;
@@ -119,7 +107,6 @@ gf_event_destroy(GfEvent *event) {
 
 	events = g_list_remove(events, event);
 
-	g_free(event->e_type);
 	g_free(event->n_type);
 	g_free(event->name);
 	g_free(event->description);
@@ -127,13 +114,6 @@ gf_event_destroy(GfEvent *event) {
 	g_free(event);
 }
 
-const gchar *
-gf_event_get_event_type(GfEvent *event) {
-	g_return_val_if_fail(event, GF_EVENT_TYPE_UNKNOWN);
-
-	return event->e_type;
-}
-
 const gchar *
 gf_event_get_notification_type(GfEvent *event) {
 	g_return_val_if_fail(event, NULL);
@@ -162,6 +142,13 @@ gf_event_get_description(GfEvent *event) {
 	return event->description;
 }
 
+GfEventPriority
+gf_event_get_priority(GfEvent *event) {
+	g_return_val_if_fail(event, GF_EVENT_PRIORITY_NORMAL);
+
+	return event->priority;
+}
+
 void
 gf_event_set_show(GfEvent *event, gboolean show) {
 	g_return_if_fail(event);
@@ -311,6 +298,12 @@ gf_event_should_show(const gchar *notification, GaimAccount *account) {
 	if(!gf_event_show_notification(notification))
 		return FALSE;
 
+	if(!gaim_prefs_get_bool(GF_PREF_BEHAVIOR_SHOW_WHILE_AWAY) &&
+	   account->gc->away_state)
+	{
+		return FALSE;
+	}
+
 	return TRUE;
 }
 
@@ -583,40 +576,66 @@ gf_events_init(GaimPlugin *plugin) {
 	g_return_if_fail(plugin);
 
 	/* create all of our default events */
-	gf_event_new("buddy", "sign-on", TOKENS_DEFAULT "n", _("Sign on"),
-				 _("Displayed when a buddy comes online."));
-	gf_event_new("buddy", "sign-off", TOKENS_DEFAULT "n", _("Sign off"),
-				 _("Displayed when a buddy goes offline."));
-	gf_event_new("buddy", "away", TOKENS_DEFAULT "n", _("Away"),
-				 _("Displayed when a buddy goes away."));
-	gf_event_new("buddy", "back", TOKENS_DEFAULT "n", _("Back"),
-				 _("Displayed when a buddy returns from away."));
-	gf_event_new("buddy", "idle", TOKENS_DEFAULT "n", _("Idle"),
-				 _("Displayed when a buddy goes idle."));
-	gf_event_new("buddy", "unidle", TOKENS_DEFAULT "n", _("Unidle"),
-				 _("Displayed when a buddy returns from idle."));
-	gf_event_new("conversation", "im-message", TOKENS_DEFAULT "Ccnr", _("IM message"),
-				 _("Displayed when someone sends you a message."));
-	gf_event_new("conversation", "chat-message", TOKENS_DEFAULT "Ccnr", _("Chat message"),
-				 _("Displayed when someone talks in a chat."));
-	gf_event_new("conversation", "nick-highlight", TOKENS_DEFAULT "Ccnr", _("Name spoken"),
-				 _("Displayed when someone says your nick in a chat"));
-	gf_event_new("conversation", "chat-join", TOKENS_DEFAULT "Ccnr", _("Join"),
-				 _("Displayed when someone joins a chat."));
-	gf_event_new("conversation", "chat-part", TOKENS_DEFAULT "Ccnr", _("Leave"),
-				 _("Displayed when someone leaves a chat."));
-	gf_event_new("conversation", "chat-invite", TOKENS_DEFAULT "Ccnr", _("Invited"),
-				 _("Displayed when someone invites you to a chat."));
-	gf_event_new("conversation", "typing", TOKENS_DEFAULT "Ccnr", _("Typing"),
-				 _("Displayed when someone is typing a message to you."));
-	gf_event_new("conversation", "typing-stopped", TOKENS_DEFAULT "Ccnr", _("Stopped typing"),
-				 _("Displayed when someone has stopped typing a message to you."));
-	gf_event_new("conversation", "topic-changed", TOKENS_DEFAULT "Ccnr", _("Topic changed"),
-				 _("Displayed when a topic is changed in a chat."));
-	gf_event_new("account", "warned", TOKENS_DEFAULT, _("Warned"),
-				 _("Displayed when you are warned."));
-	gf_event_new("util", GF_NOTIFICATION_MASTER, TOKENS_DEFAULT "Ccnr",
-				 _("Master"), _("Master notification for the theme editor."));
+	gf_event_new("sign-on", TOKENS_DEFAULT "n", _("Sign on"),
+				 _("Displayed when a buddy comes online."),
+				 GF_EVENT_PRIORITY_HIGHER);
+	gf_event_new("sign-off", TOKENS_DEFAULT "n", _("Sign off"),
+				 _("Displayed when a buddy goes offline."),
+				 GF_EVENT_PRIORITY_HIGHER);
+
+	gf_event_new("away", TOKENS_DEFAULT "n", _("Away"),
+				 _("Displayed when a buddy goes away."),
+				 GF_EVENT_PRIORITY_HIGH);
+	gf_event_new("back", TOKENS_DEFAULT "n", _("Back"),
+				 _("Displayed when a buddy returns from away."),
+				 GF_EVENT_PRIORITY_HIGH);
+
+	gf_event_new("idle", TOKENS_DEFAULT "n", _("Idle"),
+				 _("Displayed when a buddy goes idle."),
+				 GF_EVENT_PRIORITY_NORMAL);
+	gf_event_new("unidle", TOKENS_DEFAULT "n", _("Unidle"),
+				 _("Displayed when a buddy returns from idle."),
+				 GF_EVENT_PRIORITY_NORMAL);
+
+	gf_event_new("im-message", TOKENS_DEFAULT "Ccnr", _("IM message"),
+				 _("Displayed when someone sends you a message."),
+				 GF_EVENT_PRIORITY_HIGHEST);
+	gf_event_new("typing", TOKENS_DEFAULT "Ccnr", _("Typing"),
+				 _("Displayed when someone is typing a message to you."),
+				 GF_EVENT_PRIORITY_HIGHER);
+	gf_event_new("typing-stopped", TOKENS_DEFAULT "Ccnr", _("Stopped typing"),
+				 _("Displayed when someone has stopped typing a message to you."),
+				 GF_EVENT_PRIORITY_HIGHER);
+
+	gf_event_new("chat-message", TOKENS_DEFAULT "Ccnr", _("Chat message"),
+				 _("Displayed when someone talks in a chat."),
+				 GF_EVENT_PRIORITY_HIGHER);
+	gf_event_new("nick-highlight", TOKENS_DEFAULT "Ccnr", _("Name spoken"),
+				 _("Displayed when someone says your nick in a chat"),
+				 GF_EVENT_PRIORITY_HIGHEST);
+
+	gf_event_new("chat-join", TOKENS_DEFAULT "Ccnr", _("Join"),
+				 _("Displayed when someone joins a chat."),
+				 GF_EVENT_PRIORITY_LOW);
+	gf_event_new("chat-part", TOKENS_DEFAULT "Ccnr", _("Leave"),
+				 _("Displayed when someone leaves a chat."),
+				 GF_EVENT_PRIORITY_LOW);
+
+	gf_event_new("chat-invite", TOKENS_DEFAULT "Ccnr", _("Invited"),
+				 _("Displayed when someone invites you to a chat."),
+				 GF_EVENT_PRIORITY_HIGHEST);
+
+	gf_event_new("topic-changed", TOKENS_DEFAULT "Ccnr", _("Topic changed"),
+				 _("Displayed when a topic is changed in a chat."),
+				 GF_EVENT_PRIORITY_LOW);
+
+	gf_event_new("warned", TOKENS_DEFAULT, _("Warned"),
+				 _("Displayed when you are warned."),
+				 GF_EVENT_PRIORITY_NORMAL);
+
+	gf_event_new(GF_NOTIFICATION_MASTER, TOKENS_DEFAULT "Ccnr",
+				 _("Master"), _("Master notification for the theme editor."),
+				 GF_EVENT_PRIORITY_NORMAL);
 
 	/* add our string list pref */
 	for(l = events; l; l = l->next) {
