@@ -410,7 +410,7 @@ gf_item_text_parse_format(GfItemText *item_text, GfEventInfo *info) {
 	GString *str;
 	gchar *ret;
 	const gchar *tokens, *format, *time_format, *date_format, *warning;
-	const gchar *target, *message, *extra, *e_type;
+	const gchar *target, *message, *extra;
 	time_t rtime;
 	static char buff[80];
 	struct tm *ltime;
@@ -429,7 +429,6 @@ gf_item_text_parse_format(GfItemText *item_text, GfEventInfo *info) {
 	warning = gf_theme_options_get_warning(ops);
 
 	event = gf_event_info_get_event(info);
-	e_type = gf_event_get_event_type(event);
 	target = gf_event_info_get_target(info);
 	message = gf_event_info_get_message(info);
 	extra = gf_event_info_get_extra(info);
@@ -441,8 +440,7 @@ gf_item_text_parse_format(GfItemText *item_text, GfEventInfo *info) {
 	ltime = localtime(&rtime);
 
 	account = gf_event_info_get_account(info);
-	if(!g_ascii_strcasecmp(e_type, "conversation"))
-		conv = gf_event_info_get_conversation(info);
+	conv = gf_event_info_get_conversation(info);
 
 	while(format && format[0]) {
 		if(format[0] == '\\') {
@@ -533,7 +531,7 @@ gf_item_text_parse_format(GfItemText *item_text, GfEventInfo *info) {
 				str = g_string_append(str, gaim_network_get_public_ip());
 				break;
 			case 'M': /* month */
-				strftime(buff, sizeof(buff), "%m", ltime);
+                strftime(buff, sizeof(buff), "%m", ltime);
 				str = g_string_append(str, buff);
 				break;
 			case 'm': /* minute */
@@ -545,22 +543,29 @@ gf_item_text_parse_format(GfItemText *item_text, GfEventInfo *info) {
 				str = g_string_append(str, buff);
 				break;
 			case 'n': /* buddy screen name */
-				if(!g_ascii_strcasecmp(e_type, "buddy")) {
-					buddy = gf_event_info_get_buddy(info);
+                buddy = gf_event_info_get_buddy(info);
 
-					str = g_string_append(str, gaim_buddy_get_contact_alias(buddy));
-				} else if(!g_ascii_strcasecmp(e_type, "conversation")) {
+				if(buddy) {
+					const gchar *alias = gaim_buddy_get_contact_alias(buddy);
+					str = g_string_append(str, alias);
+				} else {
 					const gchar *target = gf_event_info_get_target(info);
 
-					if(!target)
-						break;
+					if(target) {
+						const gchar *target;
 
-					buddy = gaim_find_buddy(account,
-									gf_event_info_get_target(info));
-					if(buddy)
-						str = g_string_append(str, gaim_buddy_get_contact_alias(buddy));
-					else
-						str = g_string_append(str, gf_event_info_get_target(info));
+						target = gf_event_info_get_target(info);
+						buddy = gaim_find_buddy(account, target);
+
+						if(buddy) {
+							const gchar *alias;
+
+							alias = gaim_buddy_get_contact_alias(buddy);
+							str = g_string_append(str, alias);
+						} else {
+							str = g_string_append(str, target);
+						}
+					}
 				}
 
 				break;
@@ -568,7 +573,7 @@ gf_item_text_parse_format(GfItemText *item_text, GfEventInfo *info) {
 				str = g_string_append(str, gaim_account_get_protocol_id(account));
 				break;
 			case 'r': /* received message */
-				if(!g_ascii_strcasecmp(e_type, "conversation"))
+				if(message)
 					str = g_string_append(str, message);
 
 				break;
@@ -593,16 +598,22 @@ gf_item_text_parse_format(GfItemText *item_text, GfEventInfo *info) {
 
 				break;
 			case 'w': /* warning level */
-				if(!g_ascii_strcasecmp(e_type, "buddy")) {
-					const char *prpl_id = gaim_account_get_protocol_id(account);
+				buddy = gf_event_info_get_buddy(info);
+
+				if(buddy) {
+					const char *prpl_id;
+
+					prpl_id = gaim_account_get_protocol_id(account);
+
 					if(!g_ascii_strcasecmp(prpl_id, "prpl-toc") ||
 					   !g_ascii_strcasecmp(prpl_id, "prpl-oscar"))
 					{
-						buddy = gf_event_info_get_buddy(info);
 						g_string_append_printf(str, "%d", buddy->evil);
 					} else {
 						str = g_string_append(str, warning);
 					}
+				} else {
+					str = g_string_append(str, warning);
 				}
 
 				break;
@@ -615,11 +626,14 @@ gf_item_text_parse_format(GfItemText *item_text, GfEventInfo *info) {
 				strftime(buff, sizeof(buff), "%Y", ltime);
 				str = g_string_append(str, buff);
 				break;
-			case 'y': /* two digit year */
-				strftime(buff, sizeof(buff), "%y", ltime);
+			case 'y': { /* two digit year */
+				/* dirty hack to avoid compiler warning */
+				const gchar *fmt = "%y";
+
+				strftime(buff, sizeof(buff), fmt, ltime);
 				str = g_string_append(str, buff);
 				break;
-			default:
+			} default:
 				break;
 		}
 
