@@ -97,7 +97,7 @@ make_notebook_page(GtkNotebook *note, const gchar *text, gint position) {
 	gtk_widget_show(vbox);
 
 	label = gtk_label_new_with_mnemonic(text);
-	gtk_widget_show(vbox);
+	gtk_widget_show(label);
 
 	gtk_notebook_insert_page(note, vbox, label, position);
 
@@ -212,6 +212,7 @@ make_general_page(GtkWidget *notebook) {
 
 	sg = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 
+	/* Display Options */
 	frame = gaim_gtk_make_frame(vbox, _("Display Options"));
 	gtk_widget_show(frame);
 
@@ -227,12 +228,30 @@ make_general_page(GtkWidget *notebook) {
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
 	gtk_size_group_add_widget(sg, label);
 
+	label = gaim_gtk_prefs_dropdown(frame, _("Show while away:"),
+									GAIM_PREF_BOOLEAN,
+									GF_PREF_BEHAVIOR_SHOW_WHILE_AWAY,
+									_("Yes"), TRUE,
+									_("No"), FALSE,
+									NULL);
+	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
+	gtk_size_group_add_widget(sg, label);
+
+	label = gaim_gtk_prefs_dropdown(frame, _("Animate:"), GAIM_PREF_BOOLEAN,
+									GF_PREF_APPEARANCE_ANIMATE,
+									_("Yes"), TRUE,
+									_("No"), FALSE,
+									NULL);
+	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
+	gtk_size_group_add_widget(sg, label);
+
 	spin = gaim_gtk_prefs_labeled_spin_button(frame, _("_Display Time:"),
 											  GF_PREF_BEHAVIOR_DISPLAY_TIME,
 											  1, 60, sg);
 	label = make_label(_("seconds"), NULL);
 	gtk_box_pack_start(GTK_BOX(spin), label, FALSE, FALSE, 0);
 
+	/* Mouse Options */
 	frame = gaim_gtk_make_frame(vbox, _("Mouse"));
 	gtk_widget_show(frame);
 
@@ -453,6 +472,7 @@ struct ThemeInfoPane {
 	GtkWidget *theme_author;
 	GtkWidget *theme_website;
 	GtkWidget *theme_supports;
+	GtkWidget *theme_filename;
 };
 
 static struct GfThemeListData theme_data;
@@ -707,8 +727,6 @@ theme_list_selection_cb(GtkTreeSelection *selection, gpointer data) {
 				gtk_widget_set_sensitive(theme_data.theme_edit, FALSE);
 				gtk_widget_set_sensitive(theme_data.theme_delete, FALSE);
 			}
-
-			g_free(filename);
 		}
 
 		gtk_widget_set_sensitive(theme_data.theme_copy, TRUE);
@@ -722,24 +740,15 @@ theme_list_selection_cb(GtkTreeSelection *selection, gpointer data) {
 	gtk_label_set_text(GTK_LABEL(theme_info_pane.theme_author), author);
 	gtk_label_set_text(GTK_LABEL(theme_info_pane.theme_website), website);
 	gtk_label_set_text(GTK_LABEL(theme_info_pane.theme_supports), supports);
+	gtk_label_set_text(GTK_LABEL(theme_info_pane.theme_filename), filename);
 
-	if(name)
-		g_free(name);
-
-	if(version)
-		g_free(version);
-
-	if(description)
-		g_free(description);
-
-	if(author)
-		g_free(author);
-
-	if(website)
-		g_free(website);
-
-	if(supports)
-		g_free(supports);
+	g_free(name);
+	g_free(version);
+	g_free(description);
+	g_free(author);
+	g_free(website);
+	g_free(supports);
+	g_free(filename);
 }
 
 static GtkListStore *
@@ -1225,6 +1234,18 @@ make_theme_page(GtkWidget *notebook) {
 	gtk_box_pack_start(GTK_BOX(hbox), theme_info_pane.theme_supports,
 					   FALSE, FALSE, 0);
 
+	/* filename */
+	hbox = gtk_hbox_new(FALSE, 6);
+	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+
+	label = make_bold_label(_("Filename"), sg);
+	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
+
+	theme_info_pane.theme_filename = make_label(NULL, NULL);
+	gtk_label_set_line_wrap(GTK_LABEL(theme_info_pane.theme_filename), TRUE);
+	gtk_box_pack_start(GTK_BOX(hbox), theme_info_pane.theme_filename,
+					   FALSE, FALSE, 0);
+
 	/* show it already */
 	gtk_widget_show_all(mbox);
 }
@@ -1236,8 +1257,8 @@ static void
 make_advanced_page(GtkWidget *notebook) {
 	GtkWidget *vbox, *frame;
 	GtkSizeGroup *sg;
-#if GTK_CHECK_VERSION(2,2,0)
-	int screen_count, monitor_count;
+#if GTK_CHECK_VERSION(2,2,0) 	 
+	gint screen_count, monitor_count; 	 
 #endif
 
 	sg = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
@@ -1247,7 +1268,7 @@ make_advanced_page(GtkWidget *notebook) {
 	frame = gaim_gtk_make_frame(vbox, _("Release Notification"));
 
 	gaim_gtk_prefs_checkbox(_("Check for new releases"),
-							GF_PREF_ADVANCED_RELEASE_NOTIFICATION,
+							GF_PREF_ADVANCED_RELEASE_NOTIFICATION, 	 
 							frame);
 
 	frame = gaim_gtk_make_frame(vbox, _("Display Options"));
@@ -1255,7 +1276,6 @@ make_advanced_page(GtkWidget *notebook) {
 	gaim_gtk_prefs_labeled_spin_button(frame, _("_Max Visible Guifications:"),
 									   GF_PREF_BEHAVIOR_THROTTLE,
 									   0, 255, sg);
-
 #if GTK_CHECK_VERSION(2,2,0)
 	screen_count = gf_display_get_screen_count();
 	monitor_count = gf_display_get_monitor_count();
@@ -1264,15 +1284,16 @@ make_advanced_page(GtkWidget *notebook) {
 
 		if(screen_count > 0) {
 			gaim_gtk_prefs_labeled_spin_button(frame,
-										_("Show notifications on screen:"),
-										GF_PREF_ADVANCED_SCREEN,
-										0, screen_count, sg);
+											_("Show notifications on screen:"),
+											GF_PREF_ADVANCED_SCREEN,
+											0, screen_count, sg);
 		}
+
 		if(monitor_count > 0) {
 			gaim_gtk_prefs_labeled_spin_button(frame,
-										_("Show notifications on monitor:"),
-										GF_PREF_ADVANCED_MONITOR,
-										0, monitor_count, sg);
+											_("Show notifications on monitor:"),
+											GF_PREF_ADVANCED_MONITOR,
+											0, monitor_count, sg);
 		}
 	}
 #endif /* GTK_CHECK_VERSION(2,2,0) */
@@ -1280,6 +1301,9 @@ make_advanced_page(GtkWidget *notebook) {
 	gtk_widget_show_all(vbox);
 }
 
+/*******************************************************************************
+ * Callbacks
+ ******************************************************************************/
 static void
 gf_preferences_notebook_destroy_cb(GtkObject *obj, gpointer data) {
 	theme_data.tree = NULL;
@@ -1327,6 +1351,7 @@ gf_preferences_add() {
 	gaim_prefs_add_none(GF_PREF_APPEARANCE_ROOT);
 	gaim_prefs_add_int(GF_PREF_APPEARANCE_POSITION, GF_DISPLAY_POSITION_SE);
 	gaim_prefs_add_bool(GF_PREF_APPEARANCE_VERTICAL, TRUE);
+	gaim_prefs_add_bool(GF_PREF_APPEARANCE_ANIMATE, TRUE);
 
 	gaim_prefs_add_none(GF_PREF_MOUSE_ROOT);
 	gaim_prefs_add_string(GF_PREF_MOUSE_LEFT, "open");
