@@ -28,10 +28,12 @@
 #define GF_PREF_BEHAVIOR_NOTIFICATIONS "/plugins/gtk/amc_grim/guifications2/behavior/notifications"
 #define GF_PREF_BEHAVIOR_DISPLAY_TIME "/plugins/gtk/amc_grim/guifications2/behavior/display_time"
 #define GF_PREF_BEHAVIOR_THROTTLE "/plugins/gtk/amc_grim/guifications2/behavior/throttle"
+#define GF_PREF_BEHAVIOR_SHOW_WHILE_AWAY "/plugins/gtk/amc_grim/guifications2/behavior/show_while_away"
 
 #define GF_PREF_APPEARANCE_ROOT "/plugins/gtk/amc_grim/guifications2/appearance"
 #define GF_PREF_APPEARANCE_POSITION "/plugins/gtk/amc_grim/guifications2/appearance/position"
 #define GF_PREF_APPEARANCE_VERTICAL "/plugins/gtk/amc_grim/guifications2/appearance/vertical"
+#define GF_PREF_APPEARANCE_ANIMATE "/plugins/gtk/amc_grim/guifications2/appearance/animate"
 
 #define GF_PREF_MOUSE_ROOT "/plugins/gtk/amc_grim/guifications2/mouse"
 #define GF_PREF_MOUSE_LEFT "/plugins/gtk/amc_grim/guifications2/mouse/left"
